==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/AppArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin

import com.pulumi.azurenative.appplatform.AppArgs.builder
import com.pulumi.azurenative.appplatform.kotlin.inputs.AppResourcePropertiesArgs
import com.pulumi.azurenative.appplatform.kotlin.inputs.AppResourcePropertiesArgsBuilder
import com.pulumi.azurenative.appplatform.kotlin.inputs.ManagedIdentityPropertiesArgs
import com.pulumi.azurenative.appplatform.kotlin.inputs.ManagedIdentityPropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * App resource payload
 * Azure REST API version: 2023-05-01-preview. Prior API version in Azure Native 1.x: 2020-07-01.
 * Other available API versions: 2023-07-01-preview, 2023-09-01-preview, 2023-11-01-preview.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:appplatform:App myapp /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppPlatform/Spring/{serviceName}/apps/{appName}
 * ```
 * @property appName The name of the App resource.
 * @property identity The Managed Identity type of the app resource
 * @property location The GEO location of the application, always the same with its parent resource
 * @property properties Properties of the App resource
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serviceName The name of the Service resource.
 */
public data class AppArgs(
    public val appName: Output<String>? = null,
    public val identity: Output<ManagedIdentityPropertiesArgs>? = null,
    public val location: Output<String>? = null,
    public val properties: Output<AppResourcePropertiesArgs>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val serviceName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.AppArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.AppArgs =
        com.pulumi.azurenative.appplatform.AppArgs.builder()
            .appName(appName?.applyValue({ args0 -> args0 }))
            .identity(identity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .location(location?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .serviceName(serviceName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AppArgs].
 */
@PulumiTagMarker
public class AppArgsBuilder internal constructor() {
    private var appName: Output<String>? = null

    private var identity: Output<ManagedIdentityPropertiesArgs>? = null

    private var location: Output<String>? = null

    private var properties: Output<AppResourcePropertiesArgs>? = null

    private var resourceGroupName: Output<String>? = null

    private var serviceName: Output<String>? = null

    /**
     * @param value The name of the App resource.
     */
    @JvmName("hpmanwlqwhbbctqk")
    public suspend fun appName(`value`: Output<String>) {
        this.appName = value
    }

    /**
     * @param value The Managed Identity type of the app resource
     */
    @JvmName("xhwxudmtrsxnmrdk")
    public suspend fun identity(`value`: Output<ManagedIdentityPropertiesArgs>) {
        this.identity = value
    }

    /**
     * @param value The GEO location of the application, always the same with its parent resource
     */
    @JvmName("kpqmctnjbsxdeogq")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value Properties of the App resource
     */
    @JvmName("ltvtglywdlmfbyer")
    public suspend fun properties(`value`: Output<AppResourcePropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("elhcutamvistrmsu")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("lfadhnipvfprvrog")
    public suspend fun serviceName(`value`: Output<String>) {
        this.serviceName = value
    }

    /**
     * @param value The name of the App resource.
     */
    @JvmName("bqibsqkpepacviwk")
    public suspend fun appName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.appName = mapped
    }

    /**
     * @param value The Managed Identity type of the app resource
     */
    @JvmName("xvtiqkqddjhfabde")
    public suspend fun identity(`value`: ManagedIdentityPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identity = mapped
    }

    /**
     * @param argument The Managed Identity type of the app resource
     */
    @JvmName("mskcbiviapdofnyh")
    public suspend fun identity(argument: suspend ManagedIdentityPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedIdentityPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.identity = mapped
    }

    /**
     * @param value The GEO location of the application, always the same with its parent resource
     */
    @JvmName("ijlgwoijbdygsugr")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value Properties of the App resource
     */
    @JvmName("qkakqlotpapijnhl")
    public suspend fun properties(`value`: AppResourcePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument Properties of the App resource
     */
    @JvmName("mllyewetcfhqipkw")
    public suspend fun properties(argument: suspend AppResourcePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = AppResourcePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("jwjjmlfvcvuibevu")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("pkwqqpqpkynrvsqi")
    public suspend fun serviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceName = mapped
    }

    internal fun build(): AppArgs = AppArgs(
        appName = appName,
        identity = identity,
        location = location,
        properties = properties,
        resourceGroupName = resourceGroupName,
        serviceName = serviceName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/AppArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin

import com.pulumi.azurenative.appplatform.AppArgs.builder
import com.pulumi.azurenative.appplatform.kotlin.inputs.AppResourcePropertiesArgs
import com.pulumi.azurenative.appplatform.kotlin.inputs.AppResourcePropertiesArgsBuilder
import com.pulumi.azurenative.appplatform.kotlin.inputs.ManagedIdentityPropertiesArgs
import com.pulumi.azurenative.appplatform.kotlin.inputs.ManagedIdentityPropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * App resource payload
 * Azure REST API version: 2023-05-01-preview. Prior API version in Azure Native 1.x: 2020-07-01.
 * Other available API versions: 2023-07-01-preview, 2023-09-01-preview, 2023-11-01-preview, 2023-12-01, 2024-01-01-preview.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:appplatform:App myapp /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppPlatform/Spring/{serviceName}/apps/{appName}
 * ```
 * @property appName The name of the App resource.
 * @property identity The Managed Identity type of the app resource
 * @property location The GEO location of the application, always the same with its parent resource
 * @property properties Properties of the App resource
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serviceName The name of the Service resource.
 */
public data class AppArgs(
    public val appName: Output<String>? = null,
    public val identity: Output<ManagedIdentityPropertiesArgs>? = null,
    public val location: Output<String>? = null,
    public val properties: Output<AppResourcePropertiesArgs>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val serviceName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.AppArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.AppArgs =
        com.pulumi.azurenative.appplatform.AppArgs.builder()
            .appName(appName?.applyValue({ args0 -> args0 }))
            .identity(identity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .location(location?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .serviceName(serviceName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AppArgs].
 */
@PulumiTagMarker
public class AppArgsBuilder internal constructor() {
    private var appName: Output<String>? = null

    private var identity: Output<ManagedIdentityPropertiesArgs>? = null

    private var location: Output<String>? = null

    private var properties: Output<AppResourcePropertiesArgs>? = null

    private var resourceGroupName: Output<String>? = null

    private var serviceName: Output<String>? = null

    /**
     * @param value The name of the App resource.
     */
    @JvmName("vidjpcxawwfjxydo")
    public suspend fun appName(`value`: Output<String>) {
        this.appName = value
    }

    /**
     * @param value The Managed Identity type of the app resource
     */
    @JvmName("vuigspqttrsgpmiq")
    public suspend fun identity(`value`: Output<ManagedIdentityPropertiesArgs>) {
        this.identity = value
    }

    /**
     * @param value The GEO location of the application, always the same with its parent resource
     */
    @JvmName("ckvfarsrhmiyqtdi")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value Properties of the App resource
     */
    @JvmName("dfxsbrdshlrdfoyk")
    public suspend fun properties(`value`: Output<AppResourcePropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("thvccfmhkgigcktk")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("rirrqapplweiojax")
    public suspend fun serviceName(`value`: Output<String>) {
        this.serviceName = value
    }

    /**
     * @param value The name of the App resource.
     */
    @JvmName("batrapfrpcwycafv")
    public suspend fun appName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.appName = mapped
    }

    /**
     * @param value The Managed Identity type of the app resource
     */
    @JvmName("xgdsiqhtmisnyonj")
    public suspend fun identity(`value`: ManagedIdentityPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identity = mapped
    }

    /**
     * @param argument The Managed Identity type of the app resource
     */
    @JvmName("pfwlnkvtdnxwcjjo")
    public suspend fun identity(argument: suspend ManagedIdentityPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedIdentityPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.identity = mapped
    }

    /**
     * @param value The GEO location of the application, always the same with its parent resource
     */
    @JvmName("ocbqtiwhjeyeqprh")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value Properties of the App resource
     */
    @JvmName("baftwovanjjkwwkm")
    public suspend fun properties(`value`: AppResourcePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument Properties of the App resource
     */
    @JvmName("bagrbkeuaxxciobh")
    public suspend fun properties(argument: suspend AppResourcePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = AppResourcePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("rorhkdjhfvwbqhdp")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("rxvmevaujybgjyde")
    public suspend fun serviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceName = mapped
    }

    internal fun build(): AppArgs = AppArgs(
        appName = appName,
        identity = identity,
        location = location,
        properties = properties,
        resourceGroupName = resourceGroupName,
        serviceName = serviceName,
    )
}
